# bodhilib core

bodhilib core only defines the models and interfaces for interacting with LLM components.

It does not contain any implementation. This way, this package is much more stable, less frequent changes and releases than other plugin packages in this mono-repo.
